[PATCH 1/4][SRU][F/H] Revert "UBUNTU: SAUCE: Revert "usb: core: reduce power-on-good delay time of root hub""

Chris Chiu chris.chiu at canonical.com
Tue Sep 28 05:07:29 UTC 2021


BugLink: https://bugs.launchpad.net/bugs/1945211

Revert this SAUCE commit since the formal fix is approved upstream.

Signed-off-by: Chris Chiu <chris.chiu at canonical.com>
---
 drivers/usb/core/hub.h | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/drivers/usb/core/hub.h b/drivers/usb/core/hub.h
index 2d09298adcaf..72a7d13cffc6 100644
--- a/drivers/usb/core/hub.h
+++ b/drivers/usb/core/hub.h
@@ -147,8 +147,10 @@ static inline unsigned hub_power_on_good_delay(struct usb_hub *hub)
 {
 	unsigned delay = hub->descriptor->bPwrOn2PwrGood * 2;
 
-	/* Wait at least 100 msec for power to become stable */
-	return max(delay, 100U);
+	if (!hub->hdev->parent)	/* root hub */
+		return delay;
+	else /* Wait at least 100 msec for power to become stable */
+		return max(delay, 100U);
 }
 
 static inline int hub_port_debounce_be_connected(struct usb_hub *hub,
-- 
2.25.1




More information about the kernel-team mailing list